hashtree_embedded_start

Function hashtree_embedded_start 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn hashtree_embedded_start( state_root: *const c_char, ) -> *mut c_void
Start an embedded daemon rooted at the supplied filesystem path.

Safety

state_root must point to a valid NUL-terminated C string for the duration of this call.