hashtree_embedded_string_free

Function hashtree_embedded_string_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn hashtree_embedded_string_free( value: *mut c_char, )
Release a string returned by this library.

Safety

A non-null value must have been returned by a Hashtree embedded FFI string function and must not previously have been freed.